Sponsor
=======

This open-source Python library for **large-scale black-box optimization** is supported by Shenzhen Fundamental
Research Program under Grant No. JCYJ20200109141235597 (2,000,000 Yuan from 2021 to 2023), granted to *Prof. Yuhui Shi*
(CSE, SUSTech @ Shenzhen, China), and actively developed by three of his group members (**Qiqi Duan**, *Chang Shao*,
and *Guochen Zhou*).

  * Now *Zhuowei Wang* from University of Technology Sydney (UTS) takes part in this library as one core developer (for
    testing).
  * Now *Mingyang Feng* from University of Birmingham (UoB) helps to search papers involved in this library and test on
    MacOS X.
  * Now *Yijun Yang* from UTS helps to suggest papers about Bayesian Optimization (BO).
  * Now *Qi Zhao* from Southern University of Science and Technology (SUSTech) helps to proofread all the documents.

We also acknowledge the initial (2017) discussions with Hao Tong (when at SUSTech) and recent (2022) discussions wih
Changwu Huang (at SUSTech).
